==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translation>Добавить пользовательское свойство</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translation>Имя:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>Значение:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PropertyEditor.js" line="+1320"/>
        <source>*VARIES*</source>
        <translation>*РАЗНЫЕ*</translation>
    </message>
    <message>
        <location line="-1132"/>
        <source>:</source>
        <translation>:</translation>
    </message>
    <message>
        <location line="+150"/>
        <source>No Selection</source>
        <translation>Ничего не выбрано</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Specific Properties</source>
        <translation>Специфичные свойства</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation>Зависимые объекты</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translation>Пользовательский</translation>
    </message>
    <message>
        <location line="+166"/>
        <source>Index</source>
        <translation>Индекс</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Remove this property from selected objects</source>
        <translation>Удалить это свойство из выделенных объектов</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>All</source>
        <translation>Все</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Add custom property to selected objects</source>
        <translation>Удалить пользовательское свойство к выделенным объектам</translation>
    </message>
    <message>
        <location line="+136"/>
        <source>Auto</source>
        <translation>Автоматический</translation>
    </message>
    <message>
        <location line="+123"/>
        <source>Use auto measurement</source>
        <translation>Использовать автоматическое измерение</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location line="+320"/>
        <location line="+57"/>
        <location line="+11"/>
        <source>Property Editor</source>
        <translation>Редактор Свойств</translation>
    </message>
    <message>
        <location line="-68"/>
        <source>Widgets</source>
        <translation>Виджеты</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translation>Выделение:</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General Properties</source>
        <translation>Общие свойства</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Color:</source>
        <translation>Цвет:</translation>
    </message>
    <message>
        <source>Move Selection to a New Layer</source>
        <translation type="vanished">Перенос выделения на новый слой</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Linetype Scale:</source>
        <translation>Масштаб типа линии:</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Protected:</source>
        <translation>Защищённый:</translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Handle:</source>
        <translation>Обработчик:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Display Z coordinates</source>
        <translation>Отобразить координаты Z</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Display properties of current block and current layer</source>
        <translation>Отображать свойства текущего блока и текущего слоя</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translation>Добавить пользовательское свойство</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translation>Имя:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>Значение:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PropertyEditor.js" line="+1392"/>
        <source>*VARIES*</source>
        <translation>*РАЗНЫЕ*</translation>
    </message>
    <message>
        <location line="-1199"/>
        <source>:</source>
        <translation>:</translation>
    </message>
    <message>
        <location line="+151"/>
        <source>No Selection</source>
        <translation>Ничего не выбрано</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Specific Properties</source>
        <translation>Специфичные свойства</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation>Зависимые объекты</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translation>Пользовательский</translation>
    </message>
    <message>
        <location line="+166"/>
        <source>Index</source>
        <translation>Индекс</translation>
    </message>
    <message>
        <location line="+77"/>
        <source>Remove this property from selected objects</source>
        <translation>Удалить это свойство из выделенных объектов</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>All</source>
        <translation>Все</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Add custom property to selected objects</source>
        <translation>Удалить пользовательское свойство к выделенным объектам</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Show all properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+117"/>
        <source>Auto</source>
        <translation>Автоматический</translation>
    </message>
    <message>
        <location line="+128"/>
        <source>Use auto measurement</source>
        <translation>Использовать автоматическое измерение</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location line="+336"/>
        <location line="+57"/>
        <location line="+11"/>
        <source>Property Editor</source>
        <translation>Редактор Свойств</translation>
    </message>
    <message>
        <location line="-68"/>
        <source>Widgets</source>
        <translation>Виджеты</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translation>Выделение:</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General Properties</source>
        <translation>Общие свойства</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Color:</source>
        <translation>Цвет:</translation>
    </message>
    <message>
        <source>Move Selection to a New Layer</source>
        <translation type="vanished">Перенос выделения на новый слой</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Linetype Scale:</source>
        <translation>Масштаб типа линии:</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Protected:</source>
        <translation>Защищённый:</translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Handle:</source>
        <translation>Обработчик:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Display Z coordinates</source>
        <translation>Отобразить координаты Z</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Display properties of current block and current layer</source>
        <translation>Отображать свойства текущего блока и текущего слоя</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Allow adding custom properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Always show all properties (this may slow down selection of entities)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
